Node

Struct Node 

pub struct Node {
    pub parameters: Parameters,
    pub snowball: Snowball,
    pub preferences: Cell<[Id; 2]>,
    pub bit: Cell<i64>,
    pub should_reset: Cell<[bool; 2]>,
    pub child0: Option<Box<Node>>,
    pub child1: Option<Box<Node>>,
}
Represents a binary node with either no child, or a single child. It handles the voting on a range of identical, virtuous, snowball instances. ref. “avalanchego/snow/consensus/snowball/tree.go#binaryNode”

Fields

parameters: Parameters

Parameters inherited from the tree.

snowball: Snowball

Runs snowball logic.

preferences: Cell<[Id; 2]>

The choices preferred at every branch in their sub-tree.

bit: Cell<i64>

The index in the Id of the choice that this node is deciding on. Will be in the range [0, 256)

should_reset: Cell<[bool; 2]>

Used as an optimization to prevent needless tree traversals. It is the continuation of shouldReset in the Tree struct.

child0: Option<Box<Node>>

The child is the potentially none, node that votes on the next bits in the decision.

child1: Option<Box<Node>>

Implementations

Source

impl Node

pub fn preference(&self) -> Id

pub fn decided_prefix(&self) -> i64

pub fn finalized(&self) -> bool

pub fn add(&mut self, id: &Id) -> Node

pub fn record_poll(&mut self, votes: Bag, reset: bool) -> (Node, bool)

Returns the new node and whether the vote was successful. ref. “avalanchego/snow/consensus/tree.go” “binaryNode.RecordPoll”